# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/uploader/proto/export_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tensorboard.uploader.proto import blob_pb2 as tensorboard_dot_uploader_dot_proto_dot_blob__pb2
from tensorboard.uploader.proto import experiment_pb2 as tensorboard_dot_uploader_dot_proto_dot_experiment__pb2
from tensorboard.compat.proto import summary_pb2 as tensorboard_dot_compat_dot_proto_dot_summary__pb2
from tensorboard.compat.proto import tensor_pb2 as tensorboard_dot_compat_dot_proto_dot_tensor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorboard/uploader/proto/export_service.proto',
  package='tensorboard.service',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n/tensorboard/uploader/proto/export_service.proto\x12\x13tensorboard.service\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%tensorboard/uploader/proto/blob.proto\x1a+tensorboard/uploader/proto/experiment.proto\x1a&tensorboard/compat/proto/summary.proto\x1a%tensorboard/compat/proto/tensor.proto\"\xad\x01\n\x18StreamExperimentsRequest\x12\x32\n\x0eread_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x03\x12=\n\x10\x65xperiments_mask\x18\x04 \x01(\x0b\x32#.tensorboard.service.ExperimentMask\"i\n\x19StreamExperimentsResponse\x12\x16\n\x0e\x65xperiment_ids\x18\x01 \x03(\t\x12\x34\n\x0b\x65xperiments\x18\x02 \x03(\x0b\x32\x1f.tensorboard.service.Experiment\"h\n\x1bStreamExperimentDataRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x32\n\x0eread_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xe4\x05\n\x1cStreamExperimentDataResponse\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12\x10\n\x08run_name\x18\x02 \x01(\t\x12\x32\n\x0ctag_metadata\x18\x03 \x01(\x0b\x32\x1c.tensorboard.SummaryMetadata\x12P\n\x06points\x18\x04 \x01(\x0b\x32>.tensorboard.service.StreamExperimentDataResponse.ScalarPointsH\x00\x12Q\n\x07tensors\x18\x05 \x01(\x0b\x32>.tensorboard.service.StreamExperimentDataResponse.TensorPointsH\x00\x12^\n\x0e\x62lob_sequences\x18\x06 \x01(\x0b\x32\x44.tensorboard.service.StreamExperimentDataResponse.BlobSequencePointsH\x00\x1a]\n\x0cScalarPoints\x12\r\n\x05steps\x18\x01 \x03(\x03\x12.\n\nwall_times\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06values\x18\x03 \x03(\x01\x1aw\n\x0cTensorPoints\x12\r\n\x05steps\x18\x01 \x03(\x03\x12.\n\nwall_times\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x06values\x18\x03 \x03(\x0b\x32\x18.tensorboard.TensorProto\x1a\x86\x01\n\x12\x42lobSequencePoints\x12\r\n\x05steps\x18\x01 \x03(\x03\x12.\n\nwall_times\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x06values\x18\x03 \x03(\x0b\x32!.tensorboard.service.BlobSequenceB\x06\n\x04\x64\x61ta\"(\n\x15StreamBlobDataRequest\x12\x0f\n\x07\x62lob_id\x18\x01 \x01(\t\"g\n\x16StreamBlobDataResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x13\n\x0b\x66inal_chunk\x18\x04 \x01(\x08\x12\x14\n\x0c\x66inal_crc32c\x18\x05 \x01(\x07J\x04\x08\x03\x10\x04\x32\x84\x03\n\x1aTensorBoardExporterService\x12v\n\x11StreamExperiments\x12-.tensorboard.service.StreamExperimentsRequest\x1a..tensorboard.service.StreamExperimentsResponse\"\x00\x30\x01\x12\x7f\n\x14StreamExperimentData\x12\x30.tensorboard.service.StreamExperimentDataRequest\x1a\x31.tensorboard.service.StreamExperimentDataResponse\"\x00\x30\x01\x12m\n\x0eStreamBlobData\x12*.tensorboard.service.StreamBlobDataRequest\x1a+.tensorboard.service.StreamBlobDataResponse\"\x00\x30\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,tensorboard_dot_uploader_dot_proto_dot_blob__pb2.DESCRIPTOR,tensorboard_dot_uploader_dot_proto_dot_experiment__pb2.DESCRIPTOR,tensorboard_dot_compat_dot_proto_dot_summary__pb2.DESCRIPTOR,tensorboard_dot_compat_dot_proto_dot_tensor__pb2.DESCRIPTOR,])




_STREAMEXPERIMENTSREQUEST = _descriptor.Descriptor(
  name='StreamExperimentsRequest',
  full_name='tensorboard.service.StreamExperimentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='read_timestamp', full_name='tensorboard.service.StreamExperimentsRequest.read_timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='tensorboard.service.StreamExperimentsRequest.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='tensorboard.service.StreamExperimentsRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiments_mask', full_name='tensorboard.service.StreamExperimentsRequest.experiments_mask', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=442,
)


_STREAMEXPERIMENTSRESPONSE = _descriptor.Descriptor(
  name='StreamExperimentsResponse',
  full_name='tensorboard.service.StreamExperimentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_ids', full_name='tensorboard.service.StreamExperimentsResponse.experiment_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiments', full_name='tensorboard.service.StreamExperimentsResponse.experiments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=549,
)


_STREAMEXPERIMENTDATAREQUEST = _descriptor.Descriptor(
  name='StreamExperimentDataRequest',
  full_name='tensorboard.service.StreamExperimentDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='tensorboard.service.StreamExperimentDataRequest.experiment_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_timestamp', full_name='tensorboard.service.StreamExperimentDataRequest.read_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=655,
)


_STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS = _descriptor.Descriptor(
  name='ScalarPoints',
  full_name='tensorboard.service.StreamExperimentDataResponse.ScalarPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steps', full_name='tensorboard.service.StreamExperimentDataResponse.ScalarPoints.steps', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wall_times', full_name='tensorboard.service.StreamExperimentDataResponse.ScalarPoints.wall_times', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='tensorboard.service.StreamExperimentDataResponse.ScalarPoints.values', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1039,
  serialized_end=1132,
)

_STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS = _descriptor.Descriptor(
  name='TensorPoints',
  full_name='tensorboard.service.StreamExperimentDataResponse.TensorPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steps', full_name='tensorboard.service.StreamExperimentDataResponse.TensorPoints.steps', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wall_times', full_name='tensorboard.service.StreamExperimentDataResponse.TensorPoints.wall_times', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='tensorboard.service.StreamExperimentDataResponse.TensorPoints.values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1253,
)

_STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS = _descriptor.Descriptor(
  name='BlobSequencePoints',
  full_name='tensorboard.service.StreamExperimentDataResponse.BlobSequencePoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steps', full_name='tensorboard.service.StreamExperimentDataResponse.BlobSequencePoints.steps', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wall_times', full_name='tensorboard.service.StreamExperimentDataResponse.BlobSequencePoints.wall_times', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='tensorboard.service.StreamExperimentDataResponse.BlobSequencePoints.values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1390,
)

_STREAMEXPERIMENTDATARESPONSE = _descriptor.Descriptor(
  name='StreamExperimentDataResponse',
  full_name='tensorboard.service.StreamExperimentDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag_name', full_name='tensorboard.service.StreamExperimentDataResponse.tag_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_name', full_name='tensorboard.service.StreamExperimentDataResponse.run_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag_metadata', full_name='tensorboard.service.StreamExperimentDataResponse.tag_metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='tensorboard.service.StreamExperimentDataResponse.points', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tensors', full_name='tensorboard.service.StreamExperimentDataResponse.tensors', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_sequences', full_name='tensorboard.service.StreamExperimentDataResponse.blob_sequences', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS, _STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS, _STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='tensorboard.service.StreamExperimentDataResponse.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=658,
  serialized_end=1398,
)


_STREAMBLOBDATAREQUEST = _descriptor.Descriptor(
  name='StreamBlobDataRequest',
  full_name='tensorboard.service.StreamBlobDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob_id', full_name='tensorboard.service.StreamBlobDataRequest.blob_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1400,
  serialized_end=1440,
)


_STREAMBLOBDATARESPONSE = _descriptor.Descriptor(
  name='StreamBlobDataResponse',
  full_name='tensorboard.service.StreamBlobDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='tensorboard.service.StreamBlobDataResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='tensorboard.service.StreamBlobDataResponse.offset', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_chunk', full_name='tensorboard.service.StreamBlobDataResponse.final_chunk', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_crc32c', full_name='tensorboard.service.StreamBlobDataResponse.final_crc32c', index=3,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1442,
  serialized_end=1545,
)

_STREAMEXPERIMENTSREQUEST.fields_by_name['read_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEXPERIMENTSREQUEST.fields_by_name['experiments_mask'].message_type = tensorboard_dot_uploader_dot_proto_dot_experiment__pb2._EXPERIMENTMASK
_STREAMEXPERIMENTSRESPONSE.fields_by_name['experiments'].message_type = tensorboard_dot_uploader_dot_proto_dot_experiment__pb2._EXPERIMENT
_STREAMEXPERIMENTDATAREQUEST.fields_by_name['read_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS.fields_by_name['wall_times'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS.containing_type = _STREAMEXPERIMENTDATARESPONSE
_STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS.fields_by_name['wall_times'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS.fields_by_name['values'].message_type = tensorboard_dot_compat_dot_proto_dot_tensor__pb2._TENSORPROTO
_STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS.containing_type = _STREAMEXPERIMENTDATARESPONSE
_STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS.fields_by_name['wall_times'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS.fields_by_name['values'].message_type = tensorboard_dot_uploader_dot_proto_dot_blob__pb2._BLOBSEQUENCE
_STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS.containing_type = _STREAMEXPERIMENTDATARESPONSE
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['tag_metadata'].message_type = tensorboard_dot_compat_dot_proto_dot_summary__pb2._SUMMARYMETADATA
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['points'].message_type = _STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['tensors'].message_type = _STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['blob_sequences'].message_type = _STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS
_STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data'].fields.append(
  _STREAMEXPERIMENTDATARESPONSE.fields_by_name['points'])
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['points'].containing_oneof = _STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data']
_STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data'].fields.append(
  _STREAMEXPERIMENTDATARESPONSE.fields_by_name['tensors'])
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['tensors'].containing_oneof = _STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data']
_STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data'].fields.append(
  _STREAMEXPERIMENTDATARESPONSE.fields_by_name['blob_sequences'])
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['blob_sequences'].containing_oneof = _STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['StreamExperimentsRequest'] = _STREAMEXPERIMENTSREQUEST
DESCRIPTOR.message_types_by_name['StreamExperimentsResponse'] = _STREAMEXPERIMENTSRESPONSE
DESCRIPTOR.message_types_by_name['StreamExperimentDataRequest'] = _STREAMEXPERIMENTDATAREQUEST
DESCRIPTOR.message_types_by_name['StreamExperimentDataResponse'] = _STREAMEXPERIMENTDATARESPONSE
DESCRIPTOR.message_types_by_name['StreamBlobDataRequest'] = _STREAMBLOBDATAREQUEST
DESCRIPTOR.message_types_by_name['StreamBlobDataResponse'] = _STREAMBLOBDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamExperimentsRequest = _reflection.GeneratedProtocolMessageType('StreamExperimentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEXPERIMENTSREQUEST,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentsRequest)
  })
_sym_db.RegisterMessage(StreamExperimentsRequest)

StreamExperimentsResponse = _reflection.GeneratedProtocolMessageType('StreamExperimentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEXPERIMENTSRESPONSE,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentsResponse)
  })
_sym_db.RegisterMessage(StreamExperimentsResponse)

StreamExperimentDataRequest = _reflection.GeneratedProtocolMessageType('StreamExperimentDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEXPERIMENTDATAREQUEST,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentDataRequest)
  })
_sym_db.RegisterMessage(StreamExperimentDataRequest)

StreamExperimentDataResponse = _reflection.GeneratedProtocolMessageType('StreamExperimentDataResponse', (_message.Message,), {

  'ScalarPoints' : _reflection.GeneratedProtocolMessageType('ScalarPoints', (_message.Message,), {
    'DESCRIPTOR' : _STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS,
    '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentDataResponse.ScalarPoints)
    })
  ,

  'TensorPoints' : _reflection.GeneratedProtocolMessageType('TensorPoints', (_message.Message,), {
    'DESCRIPTOR' : _STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS,
    '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentDataResponse.TensorPoints)
    })
  ,

  'BlobSequencePoints' : _reflection.GeneratedProtocolMessageType('BlobSequencePoints', (_message.Message,), {
    'DESCRIPTOR' : _STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS,
    '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentDataResponse.BlobSequencePoints)
    })
  ,
  'DESCRIPTOR' : _STREAMEXPERIMENTDATARESPONSE,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentDataResponse)
  })
_sym_db.RegisterMessage(StreamExperimentDataResponse)
_sym_db.RegisterMessage(StreamExperimentDataResponse.ScalarPoints)
_sym_db.RegisterMessage(StreamExperimentDataResponse.TensorPoints)
_sym_db.RegisterMessage(StreamExperimentDataResponse.BlobSequencePoints)

StreamBlobDataRequest = _reflection.GeneratedProtocolMessageType('StreamBlobDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBLOBDATAREQUEST,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamBlobDataRequest)
  })
_sym_db.RegisterMessage(StreamBlobDataRequest)

StreamBlobDataResponse = _reflection.GeneratedProtocolMessageType('StreamBlobDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBLOBDATARESPONSE,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamBlobDataResponse)
  })
_sym_db.RegisterMessage(StreamBlobDataResponse)



_TENSORBOARDEXPORTERSERVICE = _descriptor.ServiceDescriptor(
  name='TensorBoardExporterService',
  full_name='tensorboard.service.TensorBoardExporterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1548,
  serialized_end=1936,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamExperiments',
    full_name='tensorboard.service.TensorBoardExporterService.StreamExperiments',
    index=0,
    containing_service=None,
    input_type=_STREAMEXPERIMENTSREQUEST,
    output_type=_STREAMEXPERIMENTSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StreamExperimentData',
    full_name='tensorboard.service.TensorBoardExporterService.StreamExperimentData',
    index=1,
    containing_service=None,
    input_type=_STREAMEXPERIMENTDATAREQUEST,
    output_type=_STREAMEXPERIMENTDATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StreamBlobData',
    full_name='tensorboard.service.TensorBoardExporterService.StreamBlobData',
    index=2,
    containing_service=None,
    input_type=_STREAMBLOBDATAREQUEST,
    output_type=_STREAMBLOBDATARESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TENSORBOARDEXPORTERSERVICE)

DESCRIPTOR.services_by_name['TensorBoardExporterService'] = _TENSORBOARDEXPORTERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/compat/proto/debug.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorboard/compat/proto/debug.proto',
  package='tensorboard',
  syntax='proto3',
  serialized_options=_b('\n\030org.tensorflow.frameworkB\013DebugProtosP\001ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\370\001\001'),
  serialized_pb=_b('\n$tensorboard/compat/proto/debug.proto\x12\x0btensorboard\"\x8e\x01\n\x10\x44\x65\x62ugTensorWatch\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x13\n\x0boutput_slot\x18\x02 \x01(\x05\x12\x11\n\tdebug_ops\x18\x03 \x03(\t\x12\x12\n\ndebug_urls\x18\x04 \x03(\t\x12+\n#tolerate_debug_op_creation_failures\x18\x05 \x01(\x08\"\x82\x01\n\x0c\x44\x65\x62ugOptions\x12>\n\x17\x64\x65\x62ug_tensor_watch_opts\x18\x04 \x03(\x0b\x32\x1d.tensorboard.DebugTensorWatch\x12\x13\n\x0bglobal_step\x18\n \x01(\x03\x12\x1d\n\x15reset_disk_byte_usage\x18\x0b \x01(\x08\"j\n\x12\x44\x65\x62uggedSourceFile\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x11\n\tfile_path\x18\x02 \x01(\t\x12\x15\n\rlast_modified\x18\x03 \x01(\x03\x12\r\n\x05\x62ytes\x18\x04 \x01(\x03\x12\r\n\x05lines\x18\x05 \x03(\t\"L\n\x13\x44\x65\x62uggedSourceFiles\x12\x35\n\x0csource_files\x18\x01 \x03(\x0b\x32\x1f.tensorboard.DebuggedSourceFileB\x83\x01\n\x18org.tensorflow.frameworkB\x0b\x44\x65\x62ugProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01\x62\x06proto3')
)




_DEBUGTENSORWATCH = _descriptor.Descriptor(
  name='DebugTensorWatch',
  full_name='tensorboard.DebugTensorWatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_name', full_name='tensorboard.DebugTensorWatch.node_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_slot', full_name='tensorboard.DebugTensorWatch.output_slot', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug_ops', full_name='tensorboard.DebugTensorWatch.debug_ops', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug_urls', full_name='tensorboard.DebugTensorWatch.debug_urls', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tolerate_debug_op_creation_failures', full_name='tensorboard.DebugTensorWatch.tolerate_debug_op_creation_failures', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=196,
)


_DEBUGOPTIONS = _descriptor.Descriptor(
  name='DebugOptions',
  full_name='tensorboard.DebugOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='debug_tensor_watch_opts', full_name='tensorboard.DebugOptions.debug_tensor_watch_opts', index=0,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='global_step', full_name='tensorboard.DebugOptions.global_step', index=1,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reset_disk_byte_usage', full_name='tensorboard.DebugOptions.reset_disk_byte_usage', index=2,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=199,
  serialized_end=329,
)


_DEBUGGEDSOURCEFILE = _descriptor.Descriptor(
  name='DebuggedSourceFile',
  full_name='tensorboard.DebuggedSourceFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='tensorboard.DebuggedSourceFile.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_path', full_name='tensorboard.DebuggedSourceFile.file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_modified', full_name='tensorboard.DebuggedSourceFile.last_modified', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='tensorboard.DebuggedSourceFile.bytes', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lines', full_name='tensorboard.DebuggedSourceFile.lines', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=437,
)


_DEBUGGEDSOURCEFILES = _descriptor.Descriptor(
  name='DebuggedSourceFiles',
  full_name='tensorboard.DebuggedSourceFiles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_files', full_name='tensorboard.DebuggedSourceFiles.source_files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=515,
)

_DEBUGOPTIONS.fields_by_name['debug_tensor_watch_opts'].message_type = _DEBUGTENSORWATCH
_DEBUGGEDSOURCEFILES.fields_by_name['source_files'].message_type = _DEBUGGEDSOURCEFILE
DESCRIPTOR.message_types_by_name['DebugTensorWatch'] = _DEBUGTENSORWATCH
DESCRIPTOR.message_types_by_name['DebugOptions'] = _DEBUGOPTIONS
DESCRIPTOR.message_types_by_name['DebuggedSourceFile'] = _DEBUGGEDSOURCEFILE
DESCRIPTOR.message_types_by_name['DebuggedSourceFiles'] = _DEBUGGEDSOURCEFILES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DebugTensorWatch = _reflection.GeneratedProtocolMessageType('DebugTensorWatch', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGTENSORWATCH,
  '__module__' : 'tensorboard.compat.proto.debug_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.DebugTensorWatch)
  })
_sym_db.RegisterMessage(DebugTensorWatch)

DebugOptions = _reflection.GeneratedProtocolMessageType('DebugOptions', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGOPTIONS,
  '__module__' : 'tensorboard.compat.proto.debug_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.DebugOptions)
  })
_sym_db.RegisterMessage(DebugOptions)

DebuggedSourceFile = _reflection.GeneratedProtocolMessageType('DebuggedSourceFile', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGGEDSOURCEFILE,
  '__module__' : 'tensorboard.compat.proto.debug_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.DebuggedSourceFile)
  })
_sym_db.RegisterMessage(DebuggedSourceFile)

DebuggedSourceFiles = _reflection.GeneratedProtocolMessageType('DebuggedSourceFiles', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGGEDSOURCEFILES,
  '__module__' : 'tensorboard.compat.proto.debug_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.DebuggedSourceFiles)
  })
_sym_db.RegisterMessage(DebuggedSourceFiles)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/compat/proto/config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorboard.compat.proto import cost_graph_pb2 as tensorboard_dot_compat_dot_proto_dot_cost__graph__pb2
from tensorboard.compat.proto import graph_pb2 as tensorboard_dot_compat_dot_proto_dot_graph__pb2
from tensorboard.compat.proto import step_stats_pb2 as tensorboard_dot_compat_dot_proto_dot_step__stats__pb2
from tensorboard.compat.proto import cluster_pb2 as tensorboard_dot_compat_dot_proto_dot_cluster__pb2
from tensorboard.compat.proto import coordination_config_pb2 as tensorboard_dot_compat_dot_proto_dot_coordination__config__pb2
from tensorboard.compat.proto import debug_pb2 as tensorboard_dot_compat_dot_proto_dot_debug__pb2
from tensorboard.compat.proto import rewriter_config_pb2 as tensorboard_dot_compat_dot_proto_dot_rewriter__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorboard/compat/proto/config.proto',
  package='tensorboard',
  syntax='proto3',
  serialized_options=_b('\n\030org.tensorflow.frameworkB\014ConfigProtosP\001ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\370\001\001'),
  serialized_pb=_b('\n%tensorboard/compat/proto/config.proto\x12\x0btensorboard\x1a)tensorboard/compat/proto/cost_graph.proto\x1a$tensorboard/compat/proto/graph.proto\x1a)tensorboard/compat/proto/step_stats.proto\x1a&tensorboard/compat/proto/cluster.proto\x1a\x32tensorboard/compat/proto/coordination_config.proto\x1a$tensorboard/compat/proto/debug.proto\x1a.tensorboard/compat/proto/rewriter_config.proto\"\x93\x06\n\nGPUOptions\x12\'\n\x1fper_process_gpu_memory_fraction\x18\x01 \x01(\x01\x12\x14\n\x0c\x61llow_growth\x18\x04 \x01(\x08\x12\x16\n\x0e\x61llocator_type\x18\x02 \x01(\t\x12\x1f\n\x17\x64\x65\x66\x65rred_deletion_bytes\x18\x03 \x01(\x03\x12\x1b\n\x13visible_device_list\x18\x05 \x01(\t\x12\"\n\x1apolling_active_delay_usecs\x18\x06 \x01(\x05\x12$\n\x1cpolling_inactive_delay_msecs\x18\x07 \x01(\x05\x12\x1c\n\x14\x66orce_gpu_compatible\x18\x08 \x01(\x08\x12:\n\x0c\x65xperimental\x18\t \x01(\x0b\x32$.tensorboard.GPUOptions.Experimental\x1a\xcb\x03\n\x0c\x45xperimental\x12L\n\x0fvirtual_devices\x18\x01 \x03(\x0b\x32\x33.tensorboard.GPUOptions.Experimental.VirtualDevices\x12\x1a\n\x12use_unified_memory\x18\x02 \x01(\x08\x12#\n\x1bnum_dev_to_dev_copy_streams\x18\x03 \x01(\x05\x12\x1d\n\x15\x63ollective_ring_order\x18\x04 \x01(\t\x12\x1d\n\x15timestamped_allocator\x18\x05 \x01(\x08\x12#\n\x1bkernel_tracker_max_interval\x18\x07 \x01(\x05\x12 \n\x18kernel_tracker_max_bytes\x18\x08 \x01(\x05\x12\"\n\x1akernel_tracker_max_pending\x18\t \x01(\x05\x12\'\n\x1finternal_fragmentation_fraction\x18\n \x01(\x01\x12\x1d\n\x15use_cuda_malloc_async\x18\x0b \x01(\x08\x1a;\n\x0eVirtualDevices\x12\x17\n\x0fmemory_limit_mb\x18\x01 \x03(\x02\x12\x10\n\x08priority\x18\x02 \x03(\x05\"\x9f\x03\n\x10OptimizerOptions\x12+\n#do_common_subexpression_elimination\x18\x01 \x01(\x08\x12\x1b\n\x13\x64o_constant_folding\x18\x02 \x01(\x08\x12$\n\x1cmax_folded_constant_in_bytes\x18\x06 \x01(\x03\x12\x1c\n\x14\x64o_function_inlining\x18\x04 \x01(\x08\x12\x36\n\topt_level\x18\x03 \x01(\x0e\x32#.tensorboard.OptimizerOptions.Level\x12\x46\n\x10global_jit_level\x18\x05 \x01(\x0e\x32,.tensorboard.OptimizerOptions.GlobalJitLevel\x12\x16\n\x0e\x63pu_global_jit\x18\x07 \x01(\x08\" \n\x05Level\x12\x06\n\x02L1\x10\x00\x12\x0f\n\x02L0\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\"C\n\x0eGlobalJitLevel\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x10\n\x03OFF\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x08\n\x04ON_1\x10\x01\x12\x08\n\x04ON_2\x10\x02\"\xf0\x02\n\x0cGraphOptions\x12\x1e\n\x16\x65nable_recv_scheduling\x18\x02 \x01(\x08\x12\x38\n\x11optimizer_options\x18\x03 \x01(\x0b\x32\x1d.tensorboard.OptimizerOptions\x12\x18\n\x10\x62uild_cost_model\x18\x04 \x01(\x03\x12\x1e\n\x16\x62uild_cost_model_after\x18\t \x01(\x03\x12\x14\n\x0cinfer_shapes\x18\x05 \x01(\x08\x12\x1a\n\x12place_pruned_graph\x18\x06 \x01(\x08\x12 \n\x18\x65nable_bfloat16_sendrecv\x18\x07 \x01(\x08\x12\x15\n\rtimeline_step\x18\x08 \x01(\x05\x12\x34\n\x0frewrite_options\x18\n \x01(\x0b\x32\x1b.tensorboard.RewriterConfigJ\x04\x08\x01\x10\x02R%skip_common_subexpression_elimination\"A\n\x15ThreadPoolOptionProto\x12\x13\n\x0bnum_threads\x18\x01 \x01(\x05\x12\x13\n\x0bglobal_name\x18\x02 \x01(\t\"\xd5\x01\n\nRPCOptions\x12$\n\x1cuse_rpc_for_inprocess_master\x18\x01 \x01(\x08\x12\x1d\n\x15\x63ompression_algorithm\x18\x02 \x01(\t\x12\x19\n\x11\x63ompression_level\x18\x03 \x01(\x05\x12\x1a\n\x12\x63\x61\x63he_rpc_response\x18\x04 \x01(\x08\x12*\n\"disable_session_connection_sharing\x18\x05 \x01(\x08\x12\x1f\n\x17num_channels_per_target\x18\x06 \x01(\x05\"0\n\x0fSessionMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x03\"\xb8\x0e\n\x0b\x43onfigProto\x12?\n\x0c\x64\x65vice_count\x18\x01 \x03(\x0b\x32).tensorboard.ConfigProto.DeviceCountEntry\x12$\n\x1cintra_op_parallelism_threads\x18\x02 \x01(\x05\x12$\n\x1cinter_op_parallelism_threads\x18\x05 \x01(\x05\x12\x1f\n\x17use_per_session_threads\x18\t \x01(\x08\x12H\n\x1csession_inter_op_thread_pool\x18\x0c \x03(\x0b\x32\".tensorboard.ThreadPoolOptionProto\x12\x18\n\x10placement_period\x18\x03 \x01(\x05\x12\x16\n\x0e\x64\x65vice_filters\x18\x04 \x03(\t\x12,\n\x0bgpu_options\x18\x06 \x01(\x0b\x32\x17.tensorboard.GPUOptions\x12\x1c\n\x14\x61llow_soft_placement\x18\x07 \x01(\x08\x12\x1c\n\x14log_device_placement\x18\x08 \x01(\x08\x12\x30\n\rgraph_options\x18\n \x01(\x0b\x32\x19.tensorboard.GraphOptions\x12\x1f\n\x17operation_timeout_in_ms\x18\x0b \x01(\x03\x12,\n\x0brpc_options\x18\r \x01(\x0b\x32\x17.tensorboard.RPCOptions\x12,\n\x0b\x63luster_def\x18\x0e \x01(\x0b\x32\x17.tensorboard.ClusterDef\x12\x1d\n\x15isolate_session_state\x18\x0f \x01(\x08\x12(\n share_cluster_devices_in_session\x18\x11 \x01(\x08\x12;\n\x0c\x65xperimental\x18\x10 \x01(\x0b\x32%.tensorboard.ConfigProto.Experimental\x1a\x32\n\x10\x44\x65viceCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\xab\x08\n\x0c\x45xperimental\x12\x1f\n\x17\x63ollective_group_leader\x18\x01 \x01(\t\x12\x15\n\rexecutor_type\x18\x03 \x01(\t\x12\x1a\n\x12recv_buf_max_chunk\x18\x04 \x01(\x05\x12\x19\n\x11use_numa_affinity\x18\x05 \x01(\x08\x12\x35\n-collective_deterministic_sequential_execution\x18\x06 \x01(\x08\x12\x17\n\x0f\x63ollective_nccl\x18\x07 \x01(\x08\x12\x36\n.share_session_state_in_clusterspec_propagation\x18\x08 \x01(\x08\x12\x1f\n\x17\x64isable_thread_spinning\x18\t \x01(\x08\x12(\n share_cluster_devices_in_session\x18\n \x01(\x08\x12\x36\n\x10session_metadata\x18\x0b \x01(\x0b\x32\x1c.tensorboard.SessionMetadata\x12!\n\x19optimize_for_static_graph\x18\x0c \x01(\x08\x12\x1a\n\x12\x65nable_mlir_bridge\x18\r \x01(\x08\x12T\n\x13mlir_bridge_rollout\x18\x11 \x01(\x0e\x32\x37.tensorboard.ConfigProto.Experimental.MlirBridgeRollout\x12&\n\x1e\x65nable_mlir_graph_optimization\x18\x10 \x01(\x08\x12\'\n\x1f\x64isable_output_partition_graphs\x18\x0e \x01(\x08\x12#\n\x1bxla_fusion_autotuner_thresh\x18\x0f \x01(\x03\x12\x10\n\x08use_tfrt\x18\x12 \x01(\x08\x12\'\n\x1f\x64isable_functional_ops_lowering\x18\x15 \x01(\x08\x12\'\n\x1fxla_prefer_single_graph_cluster\x18\x16 \x01(\x08\x12\x43\n\x13\x63oordination_config\x18\x17 \x01(\x0b\x32&.tensorboard.CoordinationServiceConfig\"\xda\x01\n\x11MlirBridgeRollout\x12#\n\x1fMLIR_BRIDGE_ROLLOUT_UNSPECIFIED\x10\x00\x12\x1f\n\x1bMLIR_BRIDGE_ROLLOUT_ENABLED\x10\x01\x12 \n\x1cMLIR_BRIDGE_ROLLOUT_DISABLED\x10\x02\x12)\n%MLIR_BRIDGE_ROLLOUT_SAFE_MODE_ENABLED\x10\x03\x12\x32\n.MLIR_BRIDGE_ROLLOUT_SAFE_MODE_FALLBACK_ENABLED\x10\x04J\x04\x08\x02\x10\x03J\x04\x08\x13\x10\x14J\x04\x08\x14\x10\x15\"\xe5\x04\n\nRunOptions\x12\x37\n\x0btrace_level\x18\x01 \x01(\x0e\x32\".tensorboard.RunOptions.TraceLevel\x12\x15\n\rtimeout_in_ms\x18\x02 \x01(\x03\x12\x1c\n\x14inter_op_thread_pool\x18\x03 \x01(\x05\x12\x1f\n\x17output_partition_graphs\x18\x05 \x01(\x08\x12\x30\n\rdebug_options\x18\x06 \x01(\x0b\x32\x19.tensorboard.DebugOptions\x12*\n\"report_tensor_allocations_upon_oom\x18\x07 \x01(\x08\x12:\n\x0c\x65xperimental\x18\x08 \x01(\x0b\x32$.tensorboard.RunOptions.Experimental\x1a\xd3\x01\n\x0c\x45xperimental\x12\x1c\n\x14\x63ollective_graph_key\x18\x01 \x01(\x03\x12\x1c\n\x14use_run_handler_pool\x18\x02 \x01(\x08\x12\\\n\x18run_handler_pool_options\x18\x03 \x01(\x0b\x32:.tensorboard.RunOptions.Experimental.RunHandlerPoolOptions\x1a)\n\x15RunHandlerPoolOptions\x12\x10\n\x08priority\x18\x01 \x01(\x03\"R\n\nTraceLevel\x12\x0c\n\x08NO_TRACE\x10\x00\x12\x12\n\x0eSOFTWARE_TRACE\x10\x01\x12\x12\n\x0eHARDWARE_TRACE\x10\x02\x12\x0e\n\nFULL_TRACE\x10\x03J\x04\x08\x04\x10\x05\"\x8e\x03\n\x0bRunMetadata\x12*\n\nstep_stats\x18\x01 \x01(\x0b\x32\x16.tensorboard.StepStats\x12-\n\ncost_graph\x18\x02 \x01(\x0b\x32\x19.tensorboard.CostGraphDef\x12/\n\x10partition_graphs\x18\x03 \x03(\x0b\x32\x15.tensorboard.GraphDef\x12@\n\x0f\x66unction_graphs\x18\x04 \x03(\x0b\x32\'.tensorboard.RunMetadata.FunctionGraphs\x1a\xb0\x01\n\x0e\x46unctionGraphs\x12/\n\x10partition_graphs\x18\x01 \x03(\x0b\x32\x15.tensorboard.GraphDef\x12\x35\n\x16pre_optimization_graph\x18\x02 \x01(\x0b\x32\x15.tensorboard.GraphDef\x12\x36\n\x17post_optimization_graph\x18\x03 \x01(\x0b\x32\x15.tensorboard.GraphDef\":\n\x10TensorConnection\x12\x13\n\x0b\x66rom_tensor\x18\x01 \x01(\t\x12\x11\n\tto_tensor\x18\x02 \x01(\t\"\xb4\x03\n\x0f\x43\x61llableOptions\x12\x0c\n\x04\x66\x65\x65\x64\x18\x01 \x03(\t\x12\r\n\x05\x66\x65tch\x18\x02 \x03(\t\x12\x0e\n\x06target\x18\x03 \x03(\t\x12,\n\x0brun_options\x18\x04 \x01(\x0b\x32\x17.tensorboard.RunOptions\x12\x38\n\x11tensor_connection\x18\x05 \x03(\x0b\x32\x1d.tensorboard.TensorConnection\x12\x43\n\x0c\x66\x65\x65\x64_devices\x18\x06 \x03(\x0b\x32-.tensorboard.CallableOptions.FeedDevicesEntry\x12\x45\n\rfetch_devices\x18\x07 \x03(\x0b\x32..tensorboard.CallableOptions.FetchDevicesEntry\x12\x17\n\x0f\x66\x65tch_skip_sync\x18\x08 \x01(\x08\x1a\x32\n\x10\x46\x65\x65\x64\x44\x65vicesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x46\x65tchDevicesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x84\x01\n\x18org.tensorflow.frameworkB\x0c\x43onfigProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01\x62\x06proto3')
  ,
  dependencies=[tensorboard_dot_compat_dot_proto_dot_cost__graph__pb2.DESCRIPTOR,tensorboard_dot_compat_dot_proto_dot_graph__pb2.DESCRIPTOR,tensorboard_dot_compat_dot_proto_dot_step__stats__pb2.DESCRIPTOR,tensorboard_dot_compat_dot_proto_dot_cluster__pb2.DESCRIPTOR,tensorboard_dot_compat_dot_proto_dot_coordination__config__pb2.DESCRIPTOR,tensorboard_dot_compat_dot_proto_dot_debug__pb2.DESCRIPTOR,tensorboard_dot_compat_dot_proto_dot_rewriter__config__pb2.DESCRIPTOR,])



_OPTIMIZEROPTIONS_LEVEL = _descriptor.EnumDescriptor(
  name='Level',
  full_name='tensorboard.OptimizerOptions.Level',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='L1', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='L0', index=1, number=-1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1461,
  serialized_end=1493,
)
_sym_db.RegisterEnumDescriptor(_OPTIMIZEROPTIONS_LEVEL)

_OPTIMIZEROPTIONS_GLOBALJITLEVEL = _descriptor.EnumDescriptor(
  name='GlobalJitLevel',
  full_name='tensorboard.OptimizerOptions.GlobalJitLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OFF', index=1, number=-1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ON_1', index=2, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ON_2', index=3, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1495,
  serialized_end=1562,
)
_sym_db.RegisterEnumDescriptor(_OPTIMIZEROPTIONS_GLOBALJITLEVEL)

_CONFIGPROTO_EXPERIMENTAL_MLIRBRIDGEROLLOUT = _descriptor.EnumDescriptor(
  name='MlirBridgeRollout',
  full_name='tensorboard.ConfigProto.Experimental.MlirBridgeRollout',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MLIR_BRIDGE_ROLLOUT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MLIR_BRIDGE_ROLLOUT_ENABLED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MLIR_BRIDGE_ROLLOUT_DISABLED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MLIR_BRIDGE_ROLLOUT_SAFE_MODE_ENABLED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MLIR_BRIDGE_ROLLOUT_SAFE_MODE_FALLBACK_ENABLED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3881,
  serialized_end=4099,
)
_sym_db.RegisterEnumDescriptor(_CONFIGPROTO_EXPERIMENTAL_MLIRBRIDGEROLLOUT)

_RUNOPTIONS_TRACELEVEL = _descriptor.EnumDescriptor(
  name='TraceLevel',
  full_name='tensorboard.RunOptions.TraceLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_TRACE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOFTWARE_TRACE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HARDWARE_TRACE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FULL_TRACE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4645,
  serialized_end=4727,
)
_sym_db.RegisterEnumDescriptor(_RUNOPTIONS_TRACELEVEL)


_GPUOPTIONS_EXPERIMENTAL_VIRTUALDEVICES = _descriptor.Descriptor(
  name='VirtualDevices',
  full_name='tensorboard.GPUOptions.Experimental.VirtualDevices',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory_limit_mb', full_name='tensorboard.GPUOptions.Experimental.VirtualDevices.memory_limit_mb', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priority', full_name='tensorboard.GPUOptions.Experimental.VirtualDevices.priority', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1085,
  serialized_end=1144,
)

_GPUOPTIONS_EXPERIMENTAL = _descriptor.Descriptor(
  name='Experimental',
  full_name='tensorboard.GPUOptions.Experimental',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_devices', full_name='tensorboard.GPUOptions.Experimental.virtual_devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_unified_memory', full_name='tensorboard.GPUOptions.Experimental.use_unified_memory', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_dev_to_dev_copy_streams', full_name='tensorboard.GPUOptions.Experimental.num_dev_to_dev_copy_streams', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collective_ring_order', full_name='tensorboard.GPUOptions.Experimental.collective_ring_order', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamped_allocator', full_name='tensorboard.GPUOptions.Experimental.timestamped_allocator', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kernel_tracker_max_interval', full_name='tensorboard.GPUOptions.Experimental.kernel_tracker_max_interval', index=5,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kernel_tracker_max_bytes', full_name='tensorboard.GPUOptions.Experimental.kernel_tracker_max_bytes', index=6,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kernel_tracker_max_pending', full_name='tensorboard.GPUOptions.Experimental.kernel_tracker_max_pending', index=7,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internal_fragmentation_fraction', full_name='tensorboard.GPUOptions.Experimental.internal_fragmentation_fraction', index=8,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_cuda_malloc_async', full_name='tensorboard.GPUOptions.Experimental.use_cuda_malloc_async', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GPUOPTIONS_EXPERIMENTAL_VIRTUALDEVICES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=1144,
)

_GPUOPTIONS = _descriptor.Descriptor(
  name='GPUOptions',
  full_name='tensorboard.GPUOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='per_process_gpu_memory_fraction', full_name='tensorboard.GPUOptions.per_process_gpu_memory_fraction', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allow_growth', full_name='tensorboard.GPUOptions.allow_growth', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allocator_type', full_name='tensorboard.GPUOptions.allocator_type', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deferred_deletion_bytes', full_name='tensorboard.GPUOptions.deferred_deletion_bytes', index=3,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='visible_device_list', full_name='tensorboard.GPUOptions.visible_device_list', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='polling_active_delay_usecs', full_name='tensorboard.GPUOptions.polling_active_delay_usecs', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='polling_inactive_delay_msecs', full_name='tensorboard.GPUOptions.polling_inactive_delay_msecs', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_gpu_compatible', full_name='tensorboard.GPUOptions.force_gpu_compatible', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experimental', full_name='tensorboard.GPUOptions.experimental', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GPUOPTIONS_EXPERIMENTAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=1144,
)


_OPTIMIZEROPTIONS = _descriptor.Descriptor(
  name='OptimizerOptions',
  full_name='tensorboard.OptimizerOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='do_common_subexpression_elimination', full_name='tensorboard.OptimizerOptions.do_common_subexpression_elimination', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='do_constant_folding', full_name='tensorboard.OptimizerOptions.do_constant_folding', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_folded_constant_in_bytes', full_name='tensorboard.OptimizerOptions.max_folded_constant_in_bytes', index=2,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='do_function_inlining', full_name='tensorboard.OptimizerOptions.do_function_inlining', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opt_level', full_name='tensorboard.OptimizerOptions.opt_level', index=4,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='global_jit_level', full_name='tensorboard.OptimizerOptions.global_jit_level', index=5,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu_global_jit', full_name='tensorboard.OptimizerOptions.cpu_global_jit', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPTIMIZEROPTIONS_LEVEL,
    _OPTIMIZEROPTIONS_GLOBALJITLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1147,
  serialized_end=1562,
)


_GRAPHOPTIONS = _descriptor.Descriptor(
  name='GraphOptions',
  full_name='tensorboard.GraphOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable_recv_scheduling', full_name='tensorboard.GraphOptions.enable_recv_scheduling', index=0,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizer_options', full_name='tensorboard.GraphOptions.optimizer_options', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_cost_model', full_name='tensorboard.GraphOptions.build_cost_model', index=2,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_cost_model_after', full_name='tensorboard.GraphOptions.build_cost_model_after', index=3,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infer_shapes', full_name='tensorboard.GraphOptions.infer_shapes', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='place_pruned_graph', full_name='tensorboard.GraphOptions.place_pruned_graph', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_bfloat16_sendrecv', full_name='tensorboard.GraphOptions.enable_bfloat16_sendrecv', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeline_step', full_name='tensorboard.GraphOptions.timeline_step', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_options', full_name='tensorboard.GraphOptions.rewrite_options', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1565,
  serialized_end=1933,
)


_THREADPOOLOPTIONPROTO = _descriptor.Descriptor(
  name='ThreadPoolOptionProto',
  full_name='tensorboard.ThreadPoolOptionProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_threads', full_name='tensorboard.ThreadPoolOptionProto.num_threads', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='global_name', full_name='tensorboard.ThreadPoolOptionProto.global_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1935,
  serialized_end=2000,
)


_RPCOPTIONS = _descriptor.Descriptor(
  name='RPCOptions',
  full_name='tensorboard.RPCOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_rpc_for_inprocess_master', full_name='tensorboard.RPCOptions.use_rpc_for_inprocess_master', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compression_algorithm', full_name='tensorboard.RPCOptions.compression_algorithm', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compression_level', full_name='tensorboard.RPCOptions.compression_level', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cache_rpc_response', full_name='tensorboard.RPCOptions.cache_rpc_response', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disable_session_connection_sharing', full_name='tensorboard.RPCOptions.disable_session_connection_sharing', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_channels_per_target', full_name='tensorboard.RPCOptions.num_channels_per_target', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2003,
  serialized_end=2216,
)


_SESSIONMETADATA = _descriptor.Descriptor(
  name='SessionMetadata',
  full_name='tensorboard.SessionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorboard.SessionMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='tensorboard.SessionMetadata.version', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2218,
  serialized_end=2266,
)


_CONFIGPROTO_DEVICECOUNTENTRY = _descriptor.Descriptor(
  name='DeviceCountEntry',
  full_name='tensorboard.ConfigProto.DeviceCountEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tensorboard.ConfigProto.DeviceCountEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='tensorboard.ConfigProto.DeviceCountEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2997,
  serialized_end=3047,
)

_CONFIGPROTO_EXPERIMENTAL = _descriptor.Descriptor(
  name='Experimental',
  full_name='tensorboard.ConfigProto.Experimental',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collective_group_leader', full_name='tensorboard.ConfigProto.Experimental.collective_group_leader', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executor_type', full_name='tensorboard.ConfigProto.Experimental.executor_type', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recv_buf_max_chunk', full_name='tensorboard.ConfigProto.Experimental.recv_buf_max_chunk', index=2,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_numa_affinity', full_name='tensorboard.ConfigProto.Experimental.use_numa_affinity', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collective_deterministic_sequential_execution', full_name='tensorboard.ConfigProto.Experimental.collective_deterministic_sequential_execution', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collective_nccl', full_name='tensorboard.ConfigProto.Experimental.collective_nccl', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='share_session_state_in_clusterspec_propagation', full_name='tensorboard.ConfigProto.Experimental.share_session_state_in_clusterspec_propagation', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disable_thread_spinning', full_name='tensorboard.ConfigProto.Experimental.disable_thread_spinning', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='share_cluster_devices_in_session', full_name='tensorboard.ConfigProto.Experimental.share_cluster_devices_in_session', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_metadata', full_name='tensorboard.ConfigProto.Experimental.session_metadata', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimize_for_static_graph', full_name='tensorboard.ConfigProto.Experimental.optimize_for_static_graph', index=10,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_mlir_bridge', full_name='tensorboard.ConfigProto.Experimental.enable_mlir_bridge', index=11,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mlir_bridge_rollout', full_name='tensorboard.ConfigProto.Experimental.mlir_bridge_rollout', index=12,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_mlir_graph_optimization', full_name='tensorboard.ConfigProto.Experimental.enable_mlir_graph_optimization', index=13,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disable_output_partition_graphs', full_name='tensorboard.ConfigProto.Experimental.disable_output_partition_graphs', index=14,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xla_fusion_autotuner_thresh', full_name='tensorboard.ConfigProto.Experimental.xla_fusion_autotuner_thresh', index=15,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_tfrt', full_name='tensorboard.ConfigProto.Experimental.use_tfrt', index=16,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disable_functional_ops_lowering', full_name='tensorboard.ConfigProto.Experimental.disable_functional_ops_lowering', index=17,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xla_prefer_single_graph_cluster', full_name='tensorboard.ConfigProto.Experimental.xla_prefer_single_graph_cluster', index=18,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coordination_config', full_name='tensorboard.ConfigProto.Experimental.coordination_config', index=19,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONFIGPROTO_EXPERIMENTAL_MLIRBRIDGEROLLOUT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3050,
  serialized_end=4117,
)

_CONFIGPROTO = _descriptor.Descriptor(
  name='ConfigProto',
  full_name='tensorboard.ConfigProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_count', full_name='tensorboard.ConfigProto.device_count', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intra_op_parallelism_threads', full_name='tensorboard.ConfigProto.intra_op_parallelism_threads', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inter_op_parallelism_threads', full_name='tensorboard.ConfigProto.inter_op_parallelism_threads', index=2,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_per_session_threads', full_name='tensorboard.ConfigProto.use_per_session_threads', index=3,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_inter_op_thread_pool', full_name='tensorboard.ConfigProto.session_inter_op_thread_pool', index=4,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement_period', full_name='tensorboard.ConfigProto.placement_period', index=5,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_filters', full_name='tensorboard.ConfigProto.device_filters', index=6,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpu_options', full_name='tensorboard.ConfigProto.gpu_options', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allow_soft_placement', full_name='tensorboard.ConfigProto.allow_soft_placement', index=8,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_device_placement', full_name='tensorboard.ConfigProto.log_device_placement', index=9,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_options', full_name='tensorboard.ConfigProto.graph_options', index=10,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation_timeout_in_ms', full_name='tensorboard.ConfigProto.operation_timeout_in_ms', index=11,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rpc_options', full_name='tensorboard.ConfigProto.rpc_options', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster_def', full_name='tensorboard.ConfigProto.cluster_def', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isolate_session_state', full_name='tensorboard.ConfigProto.isolate_session_state', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='share_cluster_devices_in_session', full_name='tensorboard.ConfigProto.share_cluster_devices_in_session', index=15,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experimental', full_name='tensorboard.ConfigProto.experimental', index=16,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONFIGPROTO_DEVICECOUNTENTRY, _CONFIGPROTO_EXPERIMENTAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2269,
  serialized_end=4117,
)


_RUNOPTIONS_EXPERIMENTAL_RUNHANDLERPOOLOPTIONS = _descriptor.Descriptor(
  name='RunHandlerPoolOptions',
  full_name='tensorboard.RunOptions.Experimental.RunHandlerPoolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='tensorboard.RunOptions.Experimental.RunHandlerPoolOptions.priority', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4602,
  serialized_end=4643,
)

_RUNOPTIONS_EXPERIMENTAL = _descriptor.Descriptor(
  name='Experimental',
  full_name='tensorboard.RunOptions.Experimental',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collective_graph_key', full_name='tensorboard.RunOptions.Experimental.collective_graph_key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_run_handler_pool', full_name='tensorboard.RunOptions.Experimental.use_run_handler_pool', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_handler_pool_options', full_name='tensorboard.RunOptions.Experimental.run_handler_pool_options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RUNOPTIONS_EXPERIMENTAL_RUNHANDLERPOOLOPTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4432,
  serialized_end=4643,
)

_RUNOPTIONS = _descriptor.Descriptor(
  name='RunOptions',
  full_name='tensorboard.RunOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace_level', full_name='tensorboard.RunOptions.trace_level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout_in_ms', full_name='tensorboard.RunOptions.timeout_in_ms', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inter_op_thread_pool', full_name='tensorboard.RunOptions.inter_op_thread_pool', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_partition_graphs', full_name='tensorboard.RunOptions.output_partition_graphs', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug_options', full_name='tensorboard.RunOptions.debug_options', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='report_tensor_allocations_upon_oom', full_name='tensorboard.RunOptions.report_tensor_allocations_upon_oom', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experimental', full_name='tensorboard.RunOptions.experimental', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RUNOPTIONS_EXPERIMENTAL, ],
  enum_types=[
    _RUNOPTIONS_TRACELEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4120,
  serialized_end=4733,
)


_RUNMETADATA_FUNCTIONGRAPHS = _descriptor.Descriptor(
  name='FunctionGraphs',
  full_name='tensorboard.RunMetadata.FunctionGraphs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_graphs', full_name='tensorboard.RunMetadata.FunctionGraphs.partition_graphs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_optimization_graph', full_name='tensorboard.RunMetadata.FunctionGraphs.pre_optimization_graph', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='post_optimization_graph', full_name='tensorboard.RunMetadata.FunctionGraphs.post_optimization_graph', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4958,
  serialized_end=5134,
)

_RUNMETADATA = _descriptor.Descriptor(
  name='RunMetadata',
  full_name='tensorboard.RunMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='step_stats', full_name='tensorboard.RunMetadata.step_stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_graph', full_name='tensorboard.RunMetadata.cost_graph', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_graphs', full_name='tensorboard.RunMetadata.partition_graphs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_graphs', full_name='tensorboard.RunMetadata.function_graphs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RUNMETADATA_FUNCTIONGRAPHS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4736,
  serialized_end=5134,
)


_TENSORCONNECTION = _descriptor.Descriptor(
  name='TensorConnection',
  full_name='tensorboard.TensorConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_tensor', full_name='tensorboard.TensorConnection.from_tensor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_tensor', full_name='tensorboard.TensorConnection.to_tensor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5136,
  serialized_end=5194,
)


_CALLABLEOPTIONS_FEEDDEVICESENTRY = _descriptor.Descriptor(
  name='FeedDevicesEntry',
  full_name='tensorboard.CallableOptions.FeedDevicesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tensorboard.CallableOptions.FeedDevicesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='tensorboard.CallableOptions.FeedDevicesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5530,
  serialized_end=5580,
)

_CALLABLEOPTIONS_FETCHDEVICESENTRY = _descriptor.Descriptor(
  name='FetchDevicesEntry',
  full_name='tensorboard.CallableOptions.FetchDevicesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tensorboard.CallableOptions.FetchDevicesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='tensorboard.CallableOptions.FetchDevicesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5582,
  serialized_end=5633,
)

_CALLABLEOPTIONS = _descriptor.Descriptor(
  name='CallableOptions',
  full_name='tensorboard.CallableOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed', full_name='tensorboard.CallableOptions.feed', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fetch', full_name='tensorboard.CallableOptions.fetch', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='tensorboard.CallableOptions.target', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_options', full_name='tensorboard.CallableOptions.run_options', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tensor_connection', full_name='tensorboard.CallableOptions.tensor_connection', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_devices', full_name='tensorboard.CallableOptions.feed_devices', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fetch_devices', full_name='tensorboard.CallableOptions.fetch_devices', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fetch_skip_sync', full_name='tensorboard.CallableOptions.fetch_skip_sync', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CALLABLEOPTIONS_FEEDDEVICESENTRY, _CALLABLEOPTIONS_FETCHDEVICESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5197,
  serialized_end=5633,
)

_GPUOPTIONS_EXPERIMENTAL_VIRTUALDEVICES.containing_type = _GPUOPTIONS_EXPERIMENTAL
_GPUOPTIONS_EXPERIMENTAL.fields_by_name['virtual_devices'].message_type = _GPUOPTIONS_EXPERIMENTAL_VIRTUALDEVICES
_GPUOPTIONS_EXPERIMENTAL.containing_type = _GPUOPTIONS
_GPUOPTIONS.fields_by_name['experimental'].message_type = _GPUOPTIONS_EXPERIMENTAL
_OPTIMIZEROPTIONS.fields_by_name['opt_level'].enum_type = _OPTIMIZEROPTIONS_LEVEL
_OPTIMIZEROPTIONS.fields_by_name['global_jit_level'].enum_type = _OPTIMIZEROPTIONS_GLOBALJITLEVEL
_OPTIMIZEROPTIONS_LEVEL.containing_type = _OPTIMIZEROPTIONS
_OPTIMIZEROPTIONS_GLOBALJITLEVEL.containing_type = _OPTIMIZEROPTIONS
_GRAPHOPTIONS.fields_by_name['optimizer_options'].message_type = _OPTIMIZEROPTIONS
_GRAPHOPTIONS.fields_by_name['rewrite_options'].message_type = tensorboard_dot_compat_dot_proto_dot_rewriter__config__pb2._REWRITERCONFIG
_CONFIGPROTO_DEVICECOUNTENTRY.containing_type = _CONFIGPROTO
_CONFIGPROTO_EXPERIMENTAL.fields_by_name['session_metadata'].message_type = _SESSIONMETADATA
_CONFIGPROTO_EXPERIMENTAL.fields_by_name['mlir_bridge_rollout'].enum_type = _CONFIGPROTO_EXPERIMENTAL_MLIRBRIDGEROLLOUT
_CONFIGPROTO_EXPERIMENTAL.fields_by_name['coordination_config'].message_type = tensorboard_dot_compat_dot_proto_dot_coordination__config__pb2._COORDINATIONSERVICECONFIG
_CONFIGPROTO_EXPERIMENTAL.containing_type = _CONFIGPROTO
_CONFIGPROTO_EXPERIMENTAL_MLIRBRIDGEROLLOUT.containing_type = _CONFIGPROTO_EXPERIMENTAL
_CONFIGPROTO.fields_by_name['device_count'].message_type = _CONFIGPROTO_DEVICECOUNTENTRY
_CONFIGPROTO.fields_by_name['session_inter_op_thread_pool'].message_type = _THREADPOOLOPTIONPROTO
_CONFIGPROTO.fields_by_name['gpu_options'].message_type = _GPUOPTIONS
_CONFIGPROTO.fields_by_name['graph_options'].message_type = _GRAPHOPTIONS
_CONFIGPROTO.fields_by_name['rpc_options'].message_type = _RPCOPTIONS
_CONFIGPROTO.fields_by_name['cluster_def'].message_type = tensorboard_dot_compat_dot_proto_dot_cluster__pb2._CLUSTERDEF
_CONFIGPROTO.fields_by_name['experimental'].message_type = _CONFIGPROTO_EXPERIMENTAL
_RUNOPTIONS_EXPERIMENTAL_RUNHANDLERPOOLOPTIONS.containing_type = _RUNOPTIONS_EXPERIMENTAL
_RUNOPTIONS_EXPERIMENTAL.fields_by_name['run_handler_pool_options'].message_type = _RUNOPTIONS_EXPERIMENTAL_RUNHANDLERPOOLOPTIONS
_RUNOPTIONS_EXPERIMENTAL.containing_type = _RUNOPTIONS
_RUNOPTIONS.fields_by_name['trace_level'].enum_type = _RUNOPTIONS_TRACELEVEL
_RUNOPTIONS.fields_by_name['debug_options'].message_type = tensorboard_dot_compat_dot_proto_dot_debug__pb2._DEBUGOPTIONS
_RUNOPTIONS.fields_by_name['experimental'].message_type = _RUNOPTIONS_EXPERIMENTAL
_RUNOPTIONS_TRACELEVEL.containing_type = _RUNOPTIONS
_RUNMETADATA_FUNCTIONGRAPHS.fields_by_name['partition_graphs'].message_type = tensorboard_dot_compat_dot_proto_dot_graph__pb2._GRAPHDEF
_RUNMETADATA_FUNCTIONGRAPHS.fields_by_name['pre_optimization_graph'].message_type = tensorboard_dot_compat_dot_proto_dot_graph__pb2._GRAPHDEF
_RUNMETADATA_FUNCTIONGRAPHS.fields_by_name['post_optimization_graph'].message_type = tensorboard_dot_compat_dot_proto_dot_graph__pb2._GRAPHDEF
_RUNMETADATA_FUNCTIONGRAPHS.containing_type = _RUNMETADATA
_RUNMETADATA.fields_by_name['step_stats'].message_type = tensorboard_dot_compat_dot_proto_dot_step__stats__pb2._STEPSTATS
_RUNMETADATA.fields_by_name['cost_graph'].message_type = tensorboard_dot_compat_dot_proto_dot_cost__graph__pb2._COSTGRAPHDEF
_RUNMETADATA.fields_by_name['partition_graphs'].message_type = tensorboard_dot_compat_dot_proto_dot_graph__pb2._GRAPHDEF
_RUNMETADATA.fields_by_name['function_graphs'].message_type = _RUNMETADATA_FUNCTIONGRAPHS
_CALLABLEOPTIONS_FEEDDEVICESENTRY.containing_type = _CALLABLEOPTIONS
_CALLABLEOPTIONS_FETCHDEVICESENTRY.containing_type = _CALLABLEOPTIONS
_CALLABLEOPTIONS.fields_by_name['run_options'].message_type = _RUNOPTIONS
_CALLABLEOPTIONS.fields_by_name['tensor_connection'].message_type = _TENSORCONNECTION
_CALLABLEOPTIONS.fields_by_name['feed_devices'].message_type = _CALLABLEOPTIONS_FEEDDEVICESENTRY
_CALLABLEOPTIONS.fields_by_name['fetch_devices'].message_type = _CALLABLEOPTIONS_FETCHDEVICESENTRY
DESCRIPTOR.message_types_by_name['GPUOptions'] = _GPUOPTIONS
DESCRIPTOR.message_types_by_name['OptimizerOptions'] = _OPTIMIZEROPTIONS
DESCRIPTOR.message_types_by_name['GraphOptions'] = _GRAPHOPTIONS
DESCRIPTOR.message_types_by_name['ThreadPoolOptionProto'] = _THREADPOOLOPTIONPROTO
DESCRIPTOR.message_types_by_name['RPCOptions'] = _RPCOPTIONS
DESCRIPTOR.message_types_by_name['SessionMetadata'] = _SESSIONMETADATA
DESCRIPTOR.message_types_by_name['ConfigProto'] = _CONFIGPROTO
DESCRIPTOR.message_types_by_name['RunOptions'] = _RUNOPTIONS
DESCRIPTOR.message_types_by_name['RunMetadata'] = _RUNMETADATA
DESCRIPTOR.message_types_by_name['TensorConnection'] = _TENSORCONNECTION
DESCRIPTOR.message_types_by_name['CallableOptions'] = _CALLABLEOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GPUOptions = _reflection.GeneratedProtocolMessageType('GPUOptions', (_message.Message,), {

  'Experimental' : _reflection.GeneratedProtocolMessageType('Experimental', (_message.Message,), {

    'VirtualDevices' : _reflection.GeneratedProtocolMessageType('VirtualDevices', (_message.Message,), {
      'DESCRIPTOR' : _GPUOPTIONS_EXPERIMENTAL_VIRTUALDEVICES,
      '__module__' : 'tensorboard.compat.proto.config_pb2'
      # @@protoc_insertion_point(class_scope:tensorboard.GPUOptions.Experimental.VirtualDevices)
      })
    ,
    'DESCRIPTOR' : _GPUOPTIONS_EXPERIMENTAL,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.GPUOptions.Experimental)
    })
  ,
  'DESCRIPTOR' : _GPUOPTIONS,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.GPUOptions)
  })
_sym_db.RegisterMessage(GPUOptions)
_sym_db.RegisterMessage(GPUOptions.Experimental)
_sym_db.RegisterMessage(GPUOptions.Experimental.VirtualDevices)

OptimizerOptions = _reflection.GeneratedProtocolMessageType('OptimizerOptions', (_message.Message,), {
  'DESCRIPTOR' : _OPTIMIZEROPTIONS,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.OptimizerOptions)
  })
_sym_db.RegisterMessage(OptimizerOptions)

GraphOptions = _reflection.GeneratedProtocolMessageType('GraphOptions', (_message.Message,), {
  'DESCRIPTOR' : _GRAPHOPTIONS,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.GraphOptions)
  })
_sym_db.RegisterMessage(GraphOptions)

ThreadPoolOptionProto = _reflection.GeneratedProtocolMessageType('ThreadPoolOptionProto', (_message.Message,), {
  'DESCRIPTOR' : _THREADPOOLOPTIONPROTO,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.ThreadPoolOptionProto)
  })
_sym_db.RegisterMessage(ThreadPoolOptionProto)

RPCOptions = _reflection.GeneratedProtocolMessageType('RPCOptions', (_message.Message,), {
  'DESCRIPTOR' : _RPCOPTIONS,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.RPCOptions)
  })
_sym_db.RegisterMessage(RPCOptions)

SessionMetadata = _reflection.GeneratedProtocolMessageType('SessionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONMETADATA,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.SessionMetadata)
  })
_sym_db.RegisterMessage(SessionMetadata)

ConfigProto = _reflection.GeneratedProtocolMessageType('ConfigProto', (_message.Message,), {

  'DeviceCountEntry' : _reflection.GeneratedProtocolMessageType('DeviceCountEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGPROTO_DEVICECOUNTENTRY,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ConfigProto.DeviceCountEntry)
    })
  ,

  'Experimental' : _reflection.GeneratedProtocolMessageType('Experimental', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGPROTO_EXPERIMENTAL,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ConfigProto.Experimental)
    })
  ,
  'DESCRIPTOR' : _CONFIGPROTO,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.ConfigProto)
  })
_sym_db.RegisterMessage(ConfigProto)
_sym_db.RegisterMessage(ConfigProto.DeviceCountEntry)
_sym_db.RegisterMessage(ConfigProto.Experimental)

RunOptions = _reflection.GeneratedProtocolMessageType('RunOptions', (_message.Message,), {

  'Experimental' : _reflection.GeneratedProtocolMessageType('Experimental', (_message.Message,), {

    'RunHandlerPoolOptions' : _reflection.GeneratedProtocolMessageType('RunHandlerPoolOptions', (_message.Message,), {
      'DESCRIPTOR' : _RUNOPTIONS_EXPERIMENTAL_RUNHANDLERPOOLOPTIONS,
      '__module__' : 'tensorboard.compat.proto.config_pb2'
      # @@protoc_insertion_point(class_scope:tensorboard.RunOptions.Experimental.RunHandlerPoolOptions)
      })
    ,
    'DESCRIPTOR' : _RUNOPTIONS_EXPERIMENTAL,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.RunOptions.Experimental)
    })
  ,
  'DESCRIPTOR' : _RUNOPTIONS,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.RunOptions)
  })
_sym_db.RegisterMessage(RunOptions)
_sym_db.RegisterMessage(RunOptions.Experimental)
_sym_db.RegisterMessage(RunOptions.Experimental.RunHandlerPoolOptions)

RunMetadata = _reflection.GeneratedProtocolMessageType('RunMetadata', (_message.Message,), {

  'FunctionGraphs' : _reflection.GeneratedProtocolMessageType('FunctionGraphs', (_message.Message,), {
    'DESCRIPTOR' : _RUNMETADATA_FUNCTIONGRAPHS,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.RunMetadata.FunctionGraphs)
    })
  ,
  'DESCRIPTOR' : _RUNMETADATA,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.RunMetadata)
  })
_sym_db.RegisterMessage(RunMetadata)
_sym_db.RegisterMessage(RunMetadata.FunctionGraphs)

TensorConnection = _reflection.GeneratedProtocolMessageType('TensorConnection', (_message.Message,), {
  'DESCRIPTOR' : _TENSORCONNECTION,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.TensorConnection)
  })
_sym_db.RegisterMessage(TensorConnection)

CallableOptions = _reflection.GeneratedProtocolMessageType('CallableOptions', (_message.Message,), {

  'FeedDevicesEntry' : _reflection.GeneratedProtocolMessageType('FeedDevicesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CALLABLEOPTIONS_FEEDDEVICESENTRY,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.CallableOptions.FeedDevicesEntry)
    })
  ,

  'FetchDevicesEntry' : _reflection.GeneratedProtocolMessageType('FetchDevicesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CALLABLEOPTIONS_FETCHDEVICESENTRY,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.CallableOptions.FetchDevicesEntry)
    })
  ,
  'DESCRIPTOR' : _CALLABLEOPTIONS,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.CallableOptions)
  })
_sym_db.RegisterMessage(CallableOptions)
_sym_db.RegisterMessage(CallableOptions.FeedDevicesEntry)
_sym_db.RegisterMessage(CallableOptions.FetchDevicesEntry)


DESCRIPTOR._options = None
_CONFIGPROTO_DEVICECOUNTENTRY._options = None
_CALLABLEOPTIONS_FEEDDEVICESENTRY._options = None
_CALLABLEOPTIONS_FETCHDEVICESENTRY._options = None
# @@protoc_insertion_point(module_scope)
